<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Models\Flat;
use Illuminate\Http\Request;

class FlatController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index(Request $request) {
        $search = $request->query("search");
        $perPage = $request->query("perPage") ?? 10;

        $query = Flat::with("society");

        $user = auth()->user();
        if ($user->role == "owner" || $user->role == "user") {
            $query = $query->where("society_id" == $user->society_id);
        }

        $flats = $query
            ->search($search)
            ->latest()->paginate($perPage);

        return response()->json($flats);
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request) {
        return $this->createOrUpdateFlat($request);
    }

    public function createOrUpdateFlat(Request $request, Flat $flat = new Flat()) {
        $flat->fill($request->except(["agreement", "other_docs"]));

        if ($request->hasFile('agreement')) {
            $flat->agreement = $this->storeFile($request, "agreement", "agreements");
        }

        if ($request->hasFile('other_docs')) {
            $flat->other_docs = $this->storeFile($request, "other_docs", "other_docs");
        }

        $flat->save();
        return $flat;
    }

    /**
     * Display the specified resource.
     */
    public function show(Flat $flat) {
        return $flat->loadMissing("society", "wing", "owner");
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, Flat $flat) {
        return $this->createOrUpdateFlat($request, $flat);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Flat $flat) {
        return (boolean) $flat->delete();
    }
}
