<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Models\Guard;
use App\Traits\HasStoreFile;
use Illuminate\Http\Request;

class GuardController extends Controller
{
    use HasStoreFile;

    /**
     * Display a listing of the resource.
     */
    public function index(Request $request) {
        $search = $request->query("search");
        $perPage = $request->query("perPage") ?? 10;

        $guards = Guard::with(["society", "wing"])
            ->search($search)
            ->latest()->paginate($perPage);

        return response()->json($guards);
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request) {
        return $this->createOrUpdateGuard($request);
    }

    public function createOrUpdateGuard(Request $request, Guard $guard = new Guard()): Guard {
        $guard->fill($request->except(["photo", "agreement"]));

        if ($request->hasFile('photo')) {
            $guard->photo = $this->storeFile($request, "photo", "photos");
        }

        if ($request->hasFile('agreement')) {
            $guard->agreement = $this->storeFile($request, "agreement", "agreements");
        }

        $guard->save();
        return $guard;
    }

    /**
     * Display the specified resource.
     */
    public function show(Guard $guard) {
        return $guard->loadMissing(["society", "wing"]);
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, Guard $guard) {
        return $this->createOrUpdateGuard($request, $guard);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Guard $guard) {
        return (boolean) $guard->delete();
    }
}
