<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Models\OwnerApproval;
use Illuminate\Http\Request;

class OwnerApprovalController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index(Request $request) {
        $search = $request->query("search");
        $perPage = $request->query("perPage") ?? 10;

        $user = auth()->user();
        $query = OwnerApproval::query()->with("user");

        // TODO: create role based permissions

        if ($user->role == "admin") {
            $query = $query->with("owner");
        }

        if ($user->role == "owner") {
            $query = $query->where("owner_id", $user->owner_id);
        }

        $invoices = $query->search($search)
            ->latest()->paginate($perPage);

        return response()->json($invoices);
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request) {
        $request->validate([
            "order_id" => "required|exists:owners,id",
            "user_id" => "required|exists:users,id",
        ]);

        return response()->json(OwnerApproval::query()->create($request->all()));
    }

    /**
     * Display the specified resource.
     */
    public function show(OwnerApproval $ownerApproval) {
        $user = auth()->user();
        $user->role === "admin" && $ownerApproval->loadMissing("owner");

        return $ownerApproval->loadMissing("user");
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, OwnerApproval $ownerApproval) {
        $ownerApproval->update(["is_approved" => $request->input("is_approved")]);
        $ownerApproval->user()->update(["is_approved" => $request->input("is_approved")]);
        return $ownerApproval;
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(OwnerApproval $ownerApproval) {
        return (bool) $ownerApproval->delete();
    }
}
