<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Models\Owner;
use App\Models\User;
use App\Traits\HasStoreFile;
use Illuminate\Http\Request;

class OwnerController extends Controller
{
    use HasStoreFile;

    /**
     * Display a listing of the resource.
     */
    public function index(Request $request) {
        $search = $request->query("search");
        $perPage = $request->query("perPage") ?? 10;

        $owners = Owner::with(["users", "society", "flats"])
            ->search($search)
            ->latest()->paginate($perPage);

        return response()->json($owners);
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request) {
        $owner = $this->createOrUpdateOwner($request);

        User::query()->create([
            "owner_id" => $owner->id,
            "name" => $owner->name,
            "email" => $owner->email,
            "phone" => $owner->phone,
            "password" => "password",
            "role" => "owner",
        ]);

        return $owner;
    }

    protected function createOrUpdateOwner(Request $request, Owner $owner = new Owner()): Owner {
        $owner->fill($request->except("photo"));

        if ($request->hasFile("photo")) {
            $owner->photo = $this->storeFile($request, "photo", "photos");
        }
        $owner->save();
        return $owner;
    }


    /**
     * Display the specified resource.
     */
    public function show(Owner $owner) {
        return $owner->load(["society", "flats", "users"]);
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, Owner $owner) {
        return $this->createOrUpdateOwner($request, $owner);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Owner $owner) {
        return (boolean) $owner->delete();
    }
}
