<?php

namespace App\Models;

use App\Traits\Searchable;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;

class Flat extends Model
{
    use HasFactory, Searchable;

    protected $fillable = [
        "society_id",
        "wing_id",
        "owner_id",
        "invoice_id",
        "flat_no",
        "status",
        "flat_sqrft",
    ];

    protected array $searchableFields = [];

    public function society(): BelongsTo {
        return $this->belongsTo(Society::class);
    }

    public function wing(): BelongsTo {
        return $this->belongsTo(Wing::class);
    }

    public function owner(): BelongsTo {
        return $this->belongsTo(Owner::class);
    }

    public function users(): HasMany {
        return $this->hasMany(User::class);
    }

    public function invoices(): HasMany {
        return $this->hasMany(Invoice::class);
    }

    public function parkings(): HasMany {
        return $this->hasMany(Parking::class);
    }
}
