<?php

namespace App\Models;

// use Illuminate\Contracts\Auth\MustVerifyEmail;
use App\Traits\Searchable;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Laravel\Sanctum\HasApiTokens;

class User extends Authenticatable
{
    use HasApiTokens, HasFactory, Notifiable, Searchable;

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $fillable = [
        'owner_id',
        'flat_id',
        'name',
        'email',
        'password',
        'phone',
        'role',
        'gender',
        'relation',
        'is_google_login',
    ];

    protected array $searchableFields = ["name", "email", "phone", "relation"];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'password' => "hashed",
        'email_verified_at' => 'datetime',
    ];

    public function owner(): BelongsTo {
        return $this->belongsTo(Owner::class);
    }

    public function flat(): BelongsTo {
        return $this->belongsTo(Flat::class);
    }
}
